@@ -15,7 +15,8 @@ def test_check_type_dict():
         ('k1=v1,k2=v2', {'k1': 'v1', 'k2': 'v2'}),
         ('k1=v1, k2=v2', {'k1': 'v1', 'k2': 'v2'}),
         ('k1=v1,     k2=v2,  k3=v3', {'k1': 'v1', 'k2': 'v2', 'k3': 'v3'}),
-        ('{"key": "value", "list": ["one", "two"]}', {'key': 'value', 'list': ['one', 'two']})
+        ('{"key": "value", "list": ["one", "two"]}', {'key': 'value', 'list': ['one', 'two']}),
+        ('k1=v1 k2=v2', {'k1': 'v1', 'k2': 'v2'}),
     )
     for case in test_cases:
         assert case[1] == check_type_dict(case[0])
@@ -27,6 +28,8 @@ def test_check_type_dict_fail():
         3.14159,
         [1, 2],
         'a',
+        '{1}',
+        'k1=v1 k2'
     )
     for case in test_cases:
         with pytest.raises(TypeError):
